%% The Basic Solow-Sawn Model Dynamics
% The Solow Diagram  


% Clear all and clear screen
clear
clc

%% Parameters
% Model parameters
alpha = 1/3;    %  
s     = 0.08;   % Investmetn rate
delta = 0.05;   % Depreciation rate
n     = 0.01;   % Growth of labor force
B     = 1;      % Exogenous Total-factor productivity

% Solow dynamics simualtion parameters
k0   = 1;     % Initial Capital
tMax = 100;   % Number of iterations (Dynamics 1)
tol  = 1e-05; % Tolerance (Dynamics 2)

%% Dynamics 1
% Set initial capital
K = k0;

% For each iteration compute capital in the next period
for t=1:1:tMax
    % Get current capital
    k = K(t);
    
    % Solow equation
    kinc = (s*B*k^alpha - (n+delta)*k);
    
    % Store capital in t+1
    K(t+1) = k + kinc;
    
end

% Plot capital for each iteration
plot(K)
xlabel('Iteration');
ylabel('k_t')


%% Dynamics 2: Find SS
% Set initial capital
K = k0;
kinc = Inf;
t = 0;

% For each iteration compute capital in the next period
while abs(kinc) > tol        
    % Increase t
    t = t + 1;   
    
    % Get current capital
    k = K(t);
    
    % Solow equation
    kinc = (s*B*k^alpha - (n+delta)*k);
    
    % Store capital in t+1
    K(t+1) = k + kinc; 
end

% Print the steady state value that we found
disp('DYNAMICS:');
fprintf('Steady state found after %i iterations.\n', t)
fprintf('Capital: %f\n', K(end));

% Plot capital for each iteration
figure
plot(K)
xlabel('Iteration');
ylabel('k_t')

%% Steady state (If we know the analytical solution)
% Compute steady state values
k_ss = B^(1/(1-alpha)) * (s/(n+delta))^(1/(1-alpha));
y_ss = B*(k_ss)^alpha;

% Print steady state
disp('ANALYTIC STEADE STATE VALUES:');
fprintf('Capital: %f\n', k_ss)
fprintf('Output:  %f\n', y_ss)

