%% The Basic Solow-Sawn Model Optimization
% The Solow Diagram  


% Clear all and clear screen
clear
clc

%% Parameters
% Model parameters
alpha = 1/3;    %  
s     = 0.08;   % Investmetn rate
delta = 0.05;   % Depreciation rate
n     = 0.01;   % Growth of labor force
B     = 1;      % Exogenous Total-factor productivity

%% Optimization
% Define the Solow equation as a anonymous function
solowEq = @(k) (s*B*k^alpha - (n+delta)*k);

% Set optimization options
options = optimset('Display','Iter');

% Initial Guess
x0 = 1;

% Optimize
x = fzero(solowEq,x0,options);

% Print the steady state value that we found
disp('OPTIMIZATION:');
fprintf('Steady state found by the optimizer\n')
fprintf('Capital: %f\n', x);


%% Steady state (If we know the analytical solution)
% Compute steady state values
k_ss = B^(1/(1-alpha)) * (s/(n+delta))^(1/(1-alpha));
y_ss = B*(k_ss)^alpha;

% Print steady state
disp('ANALYTIC STEADE STATE VALUES:');
fprintf('Capital: %f\n', k_ss)
fprintf('Output:  %f\n', y_ss)

